<%include file="/pageheader.html" />

## UseOPZDMX

This app allows you to import fixtures from a file in OP-Z format, such as those availble from the OFL. Simply upload your file, select a fixture type, and import it. Kaithem currently does not support fixtures with multiple modes, each mode is treated as a separate type.

Search:

### Channels

{{i}} | {{v}}

${api_link.render('api_link')}
<%include file="/pagefooter.html" />